@@ -1,7 +1,10 @@
 from datetime import timedelta, datetime
 from functools import lru_cache, wraps
+from logging import Logger
 from typing import List
 
+logger = Logger("pymultirole")
+
 
 def comma_separated_to_list(commasep: str, sep: str = ",") -> List[str]:
     commasep_aslist: List[str] = []
@@ -24,7 +27,7 @@ def timed_lru_cache(seconds: int, maxsize: int = None):
             # print('Check func expiration')
             # print(f'datetime.utcnow(): {datetime.utcnow()}, func.expiration: {func.expiration}')
             if datetime.utcnow() >= func.expiration:
-                # print('func.expiration lru_cache lifetime expired')
+                logger.info("func.expiration lru_cache lifetime expired")
                 func.cache_clear()
                 func.expiration = datetime.utcnow() + func.lifetime
 
